.. pydaivs documentation master file, created by
   sphinx-quickstart on Thu Jul  5 22:51:58 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst


.. toctree::
 :maxdepth: 2



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
